@@ -1,5 +1,5 @@
 package CGI::Builder::Magic ;
-$VERSION = 1.25 ;
+$VERSION = 1.26 ;
 
 # This file uses the "Perlish" coding style
 # please read http://perl.4pro.net/perlish_coding_style.html
@@ -47,7 +47,7 @@ $VERSION = 1.25 ;
         , default    => '.html'
         }
       , { name       => 'page_content'
-        , default    => sub{ return $print_code }
+        , default    => sub{ $print_code }
         }
       )
       
@@ -144,7 +144,7 @@ __END__
 
 CGI::Builder::Magic - CGI::Builder and Template::Magic integration
 
-=head1 VERSION 1.25
+=head1 VERSION 1.26
 
 The latest versions changes are reported in the F<Changes> file in this distribution. To have the complete list of all the extensions of the CBF, see L<CGI::Builder/"Extensions List">
 
@@ -174,8 +174,6 @@ From the directory where this file is located, type:
     make test
     make install
 
-B<Note>: The installation of this module runs an automatic version check connection which will warn you in case a newer version is available: please don't use old versions, because I can give you full support only for current versions. Besides, since CPAN does not provide any download statistic to the authors, this check allows me also to keep my own installation counter. Version checking is transparent to regular users, while CPAN testers should skip it by running the Makefile.PL with NO_VERSION_CHECK=1.
-
 =back
 
 =head1 SYNOPSIS
